mi_heap_get_backing

Function mi_heap_get_backing 

pub unsafe extern "C" fn mi_heap_get_backing() -> *mut mi_heap_t
Get the backing heap.

The backing heap is the initial default heap for a thread and always available for allocations. It cannot be destroyed or deleted except by exiting the thread.

Note: not available when using the v3 feature (removed in mimalloc v3.2).