pub unsafe extern "C" fn mi_stats_merge()Expand description
Merge thread local statistics with the main statistics and reset.
Note: This function is thread safe.
Note: not available in v3 (declared in header but not implemented).
pub unsafe extern "C" fn mi_stats_merge()Merge thread local statistics with the main statistics and reset.
Note: This function is thread safe.
Note: not available in v3 (declared in header but not implemented).